summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorMike Blumenkrantz <michael.blumenkrantz@gmail.com>2024-05-06 08:51:31 -0400
committerMarge Bot <emma+marge@anholt.net>2024-05-07 15:19:23 +0000
commit2efa1ae0d538b446cd61c837564ecdc724953f0c (patch)
treeb00c3f10f36de5bd42baa2461c341e533e402847 /include
parent9666756f603f0285d8a93ef93db1c7ec702b671f (diff)
dri: rename 'implicit' param from earlier series
I accidentally merged the wrong version of this, and this was supposed to be the correct and more informative name Acked-by: Dave Airlie <airlied@redhat.com> Part-of: <https://gitlab.freedesktop.org/mesa/mesa/-/merge_requests/29066>
Diffstat (limited to 'include')
-rw-r--r--include/GL/internal/dri_interface.h8
-rw-r--r--include/GL/internal/mesa_interface.h2
2 files changed, 5 insertions, 5 deletions
diff --git a/include/GL/internal/mesa_interface.h b/include/GL/internal/mesa_interface.h
index 85603a231c9..5cfd500f916 100644
--- a/include/GL/internal/mesa_interface.h
+++ b/include/GL/internal/mesa_interface.h
@@ -60,7 +60,7 @@ struct __DRImesaCoreExtensionRec {
__DRIcreateContextAttribsFunc createContext;
/* driver function for finishing initialization inside createNewScreen(). */
- const __DRIconfig **(*initScreen)(struct dri_screen *screen, bool implicit);
+ const __DRIconfig **(*initScreen)(struct dri_screen *screen, bool driver_name_is_inferred);
int (*queryCompatibleRenderOnlyDeviceFd)(int kms_only_fd);
diff --git a/include/GL/internal/dri_interface.h b/include/GL/internal/dri_interface.h
index f171d5084a8..06d372a30ad 100644
--- a/include/GL/internal/dri_interface.h
+++ b/include/GL/internal/dri_interface.h
@@ -968,7 +968,7 @@ struct __DRIswrastExtensionRec {
int (*queryBufferAge)(__DRIdrawable *drawable);
/**
* createNewScreen() with the driver extensions passed in and implicit load flag.
*
* \since version 6
*/
@@ -976,7 +976,7 @@ struct __DRIswrastExtensionRec {
const __DRIextension **loader_extensions,
const __DRIextension **driver_extensions,
const __DRIconfig ***driver_configs,
- bool implicit,
+ bool driver_name_is_inferred,
void *loaderPrivate);
};
@@ -995,7 +995,7 @@ typedef __DRIscreen *
const __DRIextension **extensions,
const __DRIextension **driver_extensions,
const __DRIconfig ***driver_configs,
- bool implicit,
+ bool driver_name_is_inferred,
void *loaderPrivate);
typedef __DRIdrawable *
@@ -1253,7 +1253,7 @@ struct __DRIdri2ExtensionRec {
__DRIcreateNewScreen2Func createNewScreen2;
/**
* createNewScreen with the driver's extension list passed in and implicit load flag.
*
* \since version 5
*/
@@ -968,7 +968,7 @@ struct __DRIswrastExtensionRec {
int (*queryBufferAge)(__DRIdrawable *drawable);
/**
- * createNewScreen() with the driver extensions passed in and implicit load flag.
+ * createNewScreen() with the driver extensions passed in and driver_name_is_inferred load flag.
*
* \since version 6
@@ -1253,7 +1253,7 @@ struct __DRIdri2ExtensionRec {
__DRIcreateNewScreen2Func createNewScreen2;
/**
- * createNewScreen with the driver's extension list passed in and implicit load flag.
+ * createNewScreen with the driver's extension list passed in and driver_name_is_inferred load flag.
*
* \since version 5